#
# spec file for package hylafax+
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global faxspool    %{_localstatedir}/spool/hylafax
%define lib_version %(echo %{version} | tr \. _)
Name:           hylafax+
Version:        7.0.10
Release:        1.2
Summary:        A fax server
License:        BSD-3-Clause
Group:          Productivity/Telephony/Servers
URL:            https://hylafax.sourceforge.io
Source0:        https://prdownloads.sourceforge.net/hylafax/hylafax-%{version}.tar.gz
Source4:        hylafax-hfaxd.service
Source5:        hylafax-faxq.service
Source6:        hylafax-faxgetty@.service
Source7:        hylafax.target
Source8:        README.openSUSE
Source9:        sendonly.conf
# systemd-timer
Source10:       hylafax-usage.timer
Source11:       hylafax-usage.service
Source12:       hylafax-faxqclean.timer
Source13:       hylafax-faxqclean.service
Source14:       hylafax-faxmodem@.service
Source15:       hylafax-service.xml
Source16:       hylafax-helper.xml

BuildRequires:  firewalld
BuildRequires:  gcc-c++
BuildRequires:  ghostscript
BuildRequires:  libjbig-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel >= 4.6.0t
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
# needed together with devel for proper configure detection
BuildRequires:  tiff
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(zlib)
Requires:       gawk
Requires:       ghostscript
Requires:       ghostscript-fonts
# Server checks for existence of sendfax
Requires:       hylafax+-client
Requires:       mailx
Requires:       sharutils
Requires:       tiff
Conflicts:      hylafax < 30.0.0
Conflicts:      mgetty-sendfax
Provides:       hylafax = 30.0.0
%{?systemd_requires}
%if 0%{?suse_version} >= 1500
Requires(pre):  group(uucp)
Requires(pre):  user(uucp)
%else
Requires(pre):  aaa_base
%endif

%description
HylaFAX is a fax server supporting Class 1 and 2 fax modems on UNIX
systems. It provides spooling services and numerous supporting fax
management tools. The fax clients may reside on machines different
from the server, and client implementations exist for a number of
platforms, including Windows.

%package -n libfaxutil%{lib_version}
Summary:        Runtime library needed by both fax server and client
Group:          System/Libraries

%description -n libfaxutil%{lib_version}
This runtime lib is needed by both the fax server and the client.

%package client
Summary:        Client package for the Hylafax server
Group:          Hardware/Fax
Conflicts:      hylafax-client < 30.0.0
Conflicts:      sendfax
Provides:       hylafax-client = 30.0.0

%description client
This is client part of the Hylafax fax server. If the Hylafax fax
server is already running on another machine, this package can be
used to access the server.

%prep
%autosetup -n hylafax-%{version}

cp %{SOURCE8} .
cp %{SOURCE9} .

%build
# - Can't use the configure macro because HylaFAX configure script does
#   not understand the config options used by that macro
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" \
STRIP=':' \
./configure \
        --with-DIR_BIN=%{_bindir} \
        --with-DIR_SBIN=%{_sbindir} \
        --with-DIR_LIB=%{_libdir} \
        --with-DIR_LIBEXEC=%{_sbindir} \
        --with-DIR_LIBDATA=%{_sysconfdir}/hylafax \
        --with-DIR_LOCKS=%{_localstatedir}/lock \
        --with-LIBDIR=%{_libdir} \
        --with-TIFFBIN=%{_bindir} \
        --with-DIR_MAN=%{_mandir} \
        --with-PATH_GSRIP=%{_bindir}/gs \
        --with-TIFFINC=-L%{_includedir} \
        --with-LIBTIFF="-ltiff" \
        --with-DIR_SPOOL=%{faxspool} \
        --with-AFM=no \
        --with-AWK=%{_bindir}/gawk \
        --with-PATH_VGETTY=/sbin/vgetty \
        --with-PATH_GETTY=/sbin/mgetty \
        --with-PAGESIZE=A4 \
        --with-PATH_DPSRIP=%{faxspool}/bin/ps2fax \
        --with-PATH_IMPRIP="" \
        --with-SYSVINIT=%{_initddir}/hylafax+ \
        --with-INTERACTIVE=no \
        --with-tiff-tools-unsupported=yes \
        --with-JBIGTIFF=yes
# can't use _smp_mflags because it breaks libfaxutil dso building
make -j1

%install
# install: make some dirs...
mkdir -p -m 755 %{buildroot}%{_sysconfdir}/hylafax
mkdir -p -m 755 %{buildroot}%{_unitdir}
mkdir -p -m 755 %{buildroot}%{_initddir}
mkdir -p -m 755 %{buildroot}%{_bindir}
mkdir -p -m 755 %{buildroot}%{_sbindir}
mkdir -p -m 755 %{buildroot}%{_libdir}
mkdir -p -m 755 %{buildroot}%{_mandir}
mkdir -p -m 755 %{buildroot}%{faxspool}/config

# install: binaries and man pages
# FAXUSER, FAXGROUP, SYSUSER and SYSGROUP are set to the current user to
# avoid warnings about chown/chgrp if the user building the SRPM is not root;
# they are set to the correct values with the RPM attr macro
make install -e \
        FAXUSER=`id -u` \
        FAXGROUP=`id -g` \
        SYSUSER=`id -u` \
        SYSGROUP=`id -g` \
        BIN=%{buildroot}%{_bindir} \
        SBIN=%{buildroot}%{_sbindir} \
        LIBDIR=%{buildroot}%{_libdir} \
        LIBDATA=%{buildroot}%{_sysconfdir}/hylafax \
        LIBEXEC=%{buildroot}%{_sbindir} \
        SPOOL=%{buildroot}%{faxspool} \
        MAN=%{buildroot}%{_mandir} \
        INSTALL_ROOT=%{buildroot}

install -p -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/hylafax-hfaxd.service
install -p -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/hylafax-faxq.service
install -p -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/hylafax-faxgetty@.service
install -p -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/hylafax.target
install -D -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/hylafax-usage.timer
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/hylafax-usage.service
install -D -m 0644 %{SOURCE12} %{buildroot}%{_unitdir}/hylafax-faxqclean.timer
install -D -m 0644 %{SOURCE13} %{buildroot}%{_unitdir}/hylafax-faxqclean.service
install -D -m 0644 %{SOURCE14} %{buildroot}%{_unitdir}/hylafax-faxmodem@.service
install -D -m 0644 %{SOURCE15} %{buildroot}%{_prefix}/lib/firewalld/services/hylafax.xml
install -D -m 0644 %{SOURCE16} %{buildroot}%{_prefix}/lib/firewalld/helpers/hylafax.xml

for lnk in hylafax-hfaxd hylafax-faxq; do
    ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc$lnk
done
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rchylafax

# not being executable is rather unconvenient
chmod +x %{buildroot}%{_sbindir}/edit-faxcover

# Prepare docdir by removing non-doc files
# Remove files that are not needed on Linux
rm -f %{buildroot}%{_sbindir}/{faxsetup.irix,faxsetup.bsdi}
rm -f %{buildroot}%{faxspool}/bin/{ps2fax.imp,ps2fax.dps}

rm -f %{buildroot}%{faxspool}/COPYRIGHT

%pre
%service_add_pre hylafax-faxq.service hylafax-hfaxd.service hylafax-usage.service hylafax-faxqclean.service hylafax-usage.timer hylafax-faxqclean.timer hylafax.target hylafax-faxgetty@.service hylafax-faxmodem@.service

%post
/sbin/ldconfig
%service_add_post hylafax-faxq.service hylafax-hfaxd.service hylafax-usage.service hylafax-faxqclean.service hylafax-usage.timer hylafax-faxqclean.timer hylafax.target hylafax-faxgetty@.service hylafax-faxmodem@.service

%preun
%service_del_preun hylafax-faxq.service hylafax-hfaxd.service hylafax-usage.service hylafax-faxqclean.service hylafax-usage.timer hylafax-faxqclean.timer hylafax.target hylafax-faxgetty@.service hylafax-faxmodem@.service

%postun
/sbin/ldconfig
%service_del_postun hylafax-faxq.service hylafax-hfaxd.service hylafax-usage.service hylafax-faxqclean.service hylafax-usage.timer hylafax-faxqclean.timer hylafax.target hylafax-faxgetty@.service hylafax-faxmodem@.service

%post -n libfaxutil%{lib_version} -p /sbin/ldconfig
%postun -n libfaxutil%{lib_version} -p /sbin/ldconfig

%files
%{_unitdir}/hylafax-hfaxd.service
%{_unitdir}/hylafax-faxq.service
%{_unitdir}/hylafax-faxgetty@.service
%{_unitdir}/hylafax.target
%{_unitdir}/hylafax-usage.timer
%{_unitdir}/hylafax-usage.service
%{_unitdir}/hylafax-faxqclean.timer
%{_unitdir}/hylafax-faxmodem@.service
%{_unitdir}/hylafax-faxqclean.service
%{_prefix}/lib/firewalld/services/hylafax.xml
%{_prefix}/lib/firewalld/helpers/hylafax.xml
%{_sbindir}/rchylafax-faxq
%{_sbindir}/rchylafax-hfaxd
%{_sbindir}/rchylafax
%defattr(-,root,root)
%doc CHANGES CONTRIBUTORS COPYRIGHT README TODO VERSION README.openSUSE sendonly.conf
%exclude %{_libdir}/libfaxutil*
%{_libdir}/libfax*
%{_mandir}/man5/hylafax-config.5f%{ext_man}
%{_mandir}/man5/doneq.5f%{ext_man}
%{_mandir}/man5/dialrules.5f%{ext_man}
%{_mandir}/man5/hosts.hfaxd.5f%{ext_man}
%{_mandir}/man5/hylafax-server.5f%{ext_man}
%{_mandir}/man5/hylafax-info.5f%{ext_man}
%{_mandir}/man5/hylafax-log.5f%{ext_man}
%{_mandir}/man5/pagermap.5f%{ext_man}
%{_mandir}/man5/pagesizes.5f%{ext_man}
%{_mandir}/man5/recvq.5f%{ext_man}
%{_mandir}/man5/sendq.5f%{ext_man}
%{_mandir}/man5/hylafax-shutdown.5f%{ext_man}
%{_mandir}/man5/status.5f%{ext_man}
%{_mandir}/man5/tsi.5f%{ext_man}
%{_mandir}/man5/typerules.5f%{ext_man}
%{_mandir}/man5/xferfaxlog.5f%{ext_man}
%{_mandir}/man8/choptest.8c%{ext_man}
%{_mandir}/man8/cqtest.8c%{ext_man}
%{_mandir}/man8/dialtest.8c%{ext_man}
%{_mandir}/man8/faxabort.8c%{ext_man}
%{_mandir}/man8/faxaddmodem.8c%{ext_man}
%{_mandir}/man8/faxadduser.8c%{ext_man}
%{_mandir}/man8/faxanswer.8c%{ext_man}
%{_mandir}/man8/faxconfig.8c%{ext_man}
%{_mandir}/man8/faxcron.8c%{ext_man}
%{_mandir}/man8/faxdeluser.8c%{ext_man}
%{_mandir}/man8/faxgetty.8c%{ext_man}
%{_mandir}/man8/faxinfo.8c%{ext_man}
%{_mandir}/man8/faxlock.8c%{ext_man}
%{_mandir}/man8/faxmodem.8c%{ext_man}
%{_mandir}/man8/faxq.8c%{ext_man}
%{_mandir}/man8/faxqclean.8c%{ext_man}
%{_mandir}/man8/faxquit.8c%{ext_man}
%{_mandir}/man8/faxrcvd.8c%{ext_man}
%{_mandir}/man8/faxsend.8c%{ext_man}
%{_mandir}/man8/faxsetup.8c%{ext_man}
%{_mandir}/man8/faxstate.8c%{ext_man}
%{_mandir}/man8/faxwatch.8c%{ext_man}
%{_mandir}/man8/hfaxd.8c%{ext_man}
%{_mandir}/man8/jobcontrol.8c%{ext_man}
%{_mandir}/man8/mkcover.8c%{ext_man}
%{_mandir}/man8/notify.8c%{ext_man}
%{_mandir}/man8/pagesend.8c%{ext_man}
%{_mandir}/man8/pollrcvd.8c%{ext_man}
%{_mandir}/man8/pdf2fax.8c%{ext_man}
%{_mandir}/man8/ps2fax.8c%{ext_man}
%{_mandir}/man8/recvstats.8c%{ext_man}
%{_mandir}/man8/tagtest.8c%{ext_man}
%{_mandir}/man8/tiff2fax.8c%{ext_man}
%{_mandir}/man8/tiffcheck.8c%{ext_man}
%{_mandir}/man8/tsitest.8c%{ext_man}
%{_mandir}/man8/wedged.8c%{ext_man}
%{_mandir}/man8/xferfaxstats.8c%{ext_man}
%{_mandir}/man8/faxfetch.8c%{ext_man}
%{_mandir}/man8/faxmsg.8c%{ext_man}
%{_mandir}/man8/faxsetup.linux.8c%{ext_man}
%{_mandir}/man8/hylafax.8c%{ext_man}
%{_mandir}/man8/lockname.8c%{ext_man}
%{_mandir}/man8/ondelay.8c%{ext_man}
%{_mandir}/man8/probemodem.8c%{ext_man}
%{_mandir}/man8/typetest.8c%{ext_man}
%defattr(755,root,uucp,-)
%dir %{faxspool}
%dir %{faxspool}/bin
%dir %{faxspool}%{_sysconfdir}
%dir %{faxspool}/config
%dir %{faxspool}/bin/dict
%{faxspool}/config/*
%{faxspool}/bin/dict/*
%{faxspool}/bin/genfontmap.ps
%{faxspool}/bin/auto-rotate.ps
%{faxspool}%{_sysconfdir}/dpsprinter.ps
%{faxspool}%{_sysconfdir}/cover.templ
%{faxspool}%{_sysconfdir}/lutRS18.pcf
%{faxspool}%{_sysconfdir}/LiberationSans-25.pcf
%config(noreplace) %{faxspool}%{_sysconfdir}/dialrules*
%defattr(755,root,root,-)
%dir %{_sysconfdir}/hylafax
%dir %{_sysconfdir}/hylafax/faxmail
%dir %{_sysconfdir}/hylafax/faxmail/application
%dir %{_sysconfdir}/hylafax/faxmail/image
%config(noreplace) %{_sysconfdir}/hylafax/hfaxd.conf
%{_sbindir}/choptest
%{_sbindir}/cqtest
%{_sbindir}/dialtest
%{_sbindir}/faxabort
%{_sbindir}/faxaddmodem
%{_sbindir}/faxadduser
%{_sbindir}/faxanswer
%{_sbindir}/faxconfig
%{_sbindir}/faxcron
%{_sbindir}/faxdeluser
%{_sbindir}/faxinfo
%{_sbindir}/faxlock
%{_sbindir}/faxmodem
%{_sbindir}/faxmsg
%{_sbindir}/faxq
%{_sbindir}/faxqclean
%{_sbindir}/faxquit
%{_sbindir}/faxsetup
%{_sbindir}/faxsetup.linux
%{_sbindir}/faxstate
%{_sbindir}/faxwatch
%{_sbindir}/probemodem
%{_sbindir}/recvstats
%{_sbindir}/tagtest
%{_sbindir}/tiffcheck
%{_sbindir}/tsitest
%{_sbindir}/typetest
%{_sbindir}/xferfaxstats
%{_sbindir}/faxfetch
%{_sbindir}/faxgetty
%{_sbindir}/faxsend
%{_sbindir}/hfaxd
%{_sbindir}/hylafax
%{_sbindir}/lockname
%{_sbindir}/ondelay
%{_sbindir}/pagesend
%{faxspool}/bin/archive
%{faxspool}/bin/common-functions
%{faxspool}/bin/dictionary
%{faxspool}/bin/faxrcvd
%{faxspool}/bin/mkcover
%{faxspool}/bin/notify
%{faxspool}/bin/pcl2fax
%{faxspool}/bin/pdf2fax.gs
%{faxspool}/bin/pollrcvd
%{faxspool}/bin/ps2fax.gs
%{faxspool}/bin/qp-encode.awk
%{faxspool}/bin/rfc2047-encode.awk
%{faxspool}/bin/tiff2fax
%{faxspool}/bin/tiff2pdf
%{faxspool}/bin/wedged
%{_sysconfdir}/hylafax/faxmail/application/pdf
%{_sysconfdir}/hylafax/faxmail/application/octet-stream
%{_sysconfdir}/hylafax/faxmail/application/binary
%{_sysconfdir}/hylafax/faxmail/image/tiff
%defattr(-,uucp,uucp,-)
%dir %{faxspool}/client
%dir %{faxspool}/info
%dir %{faxspool}/log
%dir %{faxspool}/recvq
%dir %{faxspool}/status
%dir %{faxspool}/dev
%config(noreplace) %{faxspool}%{_sysconfdir}/xferfaxlog
%defattr(700,uucp,uucp)
%dir %{faxspool}/docq
%dir %{faxspool}/doneq
%dir %{faxspool}/archive
%dir %{faxspool}/sendq
%dir %{faxspool}/tmp
%dir %{faxspool}/pollq
%defattr(600,uucp,uucp,-)
%config(noreplace) %{faxspool}%{_sysconfdir}/hosts.hfaxd

%files -n libfaxutil%{lib_version}
%defattr(-,root,root,-)
%{_libdir}/libfaxutil*

%files client
%config(noreplace) %{_sysconfdir}/hylafax/faxcover.ps
%config(noreplace) %{_sysconfdir}/hylafax/faxmail.ps
%config(noreplace) %{_sysconfdir}/hylafax/pagesizes
%config(noreplace) %{_sysconfdir}/hylafax/typerules
%{_bindir}/faxalter
%{_bindir}/faxcover
%{_bindir}/faxmail
%{_bindir}/faxrm
%{_bindir}/faxstat
%{_bindir}/sendfax
%{_bindir}/sendpage
%{_sbindir}/edit-faxcover
%{_sbindir}/textfmt
%{_mandir}/man1/edit-faxcover.1%{?ext_man}
%{_mandir}/man1/faxalter.1%{?ext_man}
%{_mandir}/man1/faxcover.1%{?ext_man}
%{_mandir}/man1/faxmail.1%{?ext_man}
%{_mandir}/man1/faxrm.1%{?ext_man}
%{_mandir}/man1/faxstat.1%{?ext_man}
%{_mandir}/man1/hylafax-client.1%{?ext_man}
%{_mandir}/man1/sendfax.1%{?ext_man}
%{_mandir}/man1/sendpage.1%{?ext_man}
%{_mandir}/man1/sgi2fax.1%{?ext_man}
%{_mandir}/man1/textfmt.1%{?ext_man}

%changelog
* Fri Jan 31 2025 Axel Braun <axel.braun@gmx.de>
- version 7.0.10
  * fix build for GCC v15 on Fedora 42 (23 Jan 2025)
  * identify a sender as fumbling ECM if they don't get any data through in four
    attempts at 2400 bps (16 Jan 2025)
  * extend Phase D reception attempts to at least 4-5 seconds if connected (7 Jan 2025)
  * ignore DTMF presentation in Class 1 when dialing (27 Dec 2024)
  * start SSL Fax connection on receive even if DCS is not received (15, 21 Nov 2024)
  * fix rare conditions where send error messages are omitted (12 Sep, 29 Oct 2024)
* Tue Oct  8 2024 Axel Braun <axel.braun@gmx.de>
- removed comment from spec file
* Sun Oct  6 2024 Axel Braun <axel.braun@gmx.de>
- version 7.0.9
  * add support for libtiff 4.7.0 (7 Sep 2024)
  * try to cope with T.38 invite stutter at beginning of receive (25 Aug 2024)
  * identify more senders who confuse RTN (21-24 Aug 2024)
  * cope with Phase C carrier fast restart when receiving (21 Aug 2024)
  * Support PDF form as cover page template (6 Aug 2024)
  * fix some build warnings (6 Aug 2024)
  * Correctly report file encoding with cqtest (5 Aug 2024)
  * Set FIFO response waiting flag earlier to prevent deadlock (5 Aug 2024)
  * Increasing file header buffer used to detect file type (5 Aug 2024)
  * Log invalid FIFO messages received by hfaxd (5 Aug 2024)
  * Allow triggers to work in passive mode (5 Aug 2024)
  * Abort deleting user when an error prevent writing new file (5 Aug 2024)
  * Allow recvstats to correctly show times over 99 minutes (5 Aug 2024)
  * Close both sides of the control pipe when jobcontrol fork fails (5 Aug 2024)
  * Don't log in faxq signal handler (5 Aug 2024)
  * various logging and documentation corrections (5 Aug 2024)
  * faxq: scanQueueDirectory fixup (5 Aug 2024)
  * faxq: Dispatch while we are scanning for all our jobs (5 Aug 2024)
  * ModemServer: Write freeing status to void no-longer valid status (5 Aug 2024)
  * faxq: Make debug show modems and their states too (5 Aug 2024)
  * faxdeluser: preserve current hosts file ownership and modes (5 Aug 2024)
  * Close files when done with them. (5 Aug 2024)
  * Wait for end marker before terminating SHIELDED_DTMF retrieval (5 Aug 2024)
  * Allow email headers to be folded between field-name and field-body (5 Aug 2024)
  * We need to check for child that terminate while SIGCLD is not setup. (5 Aug 2024)
  * MAXSEQNUM is a valid value to be returned. It's any above that is invalid (5 Aug 2024)
  * New option to return receive stats by device (already in xfer stats) (5 Aug 2024)
  * Get DF from params when DCS is not present/valid (5 Aug 2024)
  * Do not poll for children when checking for FD or processes already ready (5 Aug 2024)
  * Make sure all messages from a child are processed before reaping that child (5 Aug 2024)
  * Replace non signal-safe signal handlers with simple ones setting a flag (5 Aug 2024)
  * PDF2FaxCmd documentation (5 Aug 2024)
  * Make sure message didn't get truncated before sending command to FIFO (5 Aug 2024)
  * FIFO sending utilities must send NUL character at the end of commands (5 Aug 2024)
  * specify /bin/bash in faxmail scripts requiring bash (26 Apr 2024)
* Thu Mar 28 2024 Axel Braun <axel.braun@gmx.de>
- version 7.0.8
  * tiff.patch removed (included)
  * add support for libtiff 4.6.0t (20 Mar 2024)
  * don't attempt SSL Fax for the last training attempt (19 Feb 2024)
  * fix sslfaxproxy from terminating if a client doesn't provide a passcode (9 Oct 2023)
  * fix faxmail to cope with uppercase in multipart content-type header (25 Jul 2023)
  * increase SSL Fax listener backlog to system somaxconn value (24 Jul 2023)
  * improve sslfaxproxy error handling (7 Jul 2023)
  * fix handling of Phase B signals in Phase D when in V.34-Fax (10 May 2023)
  * improve V.34-Fax recovery after SSL Fax termination (10 May 2023)
  * cope with Class 1.0 V.34-Fax scenarios where we receive ECM data frames
    when we were expecting Phase D signaling (3-4 Apr 2023)
  * ignore modem input when trying to deliberately terminate a call (3 Apr 2023)
  * C99 compatibility fixes for configure script (17 Feb 2023)
  * cope with libjpeg informative messages (6, 8 Feb 2023)
  * cope with color senders that do not include G3FAX marker (4 Feb 2023)-
* Wed Feb 21 2024 Axel Braun <axel.braun@gmx.de>
- prepare for rpm 4.20
* Mon Nov 20 2023 Hans-Peter Jansen <hpj@urpla.net>
- Remove stray pseudo comment (from Bjørn Lie)
* Fri Nov 10 2023 Jan Engelhardt <jengelh@inai.de>
- Add tiff.patch to unbreak build
* Tue Jan 24 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- version 7.0.7
  * tiff_450.diff removed
  * constrain job priority to 0-255 (20 Jan 2023)
  * add support for libtiff v4.5.0 (4-5 Jan 2023)
  * add some Si2435 configuration considerations (27 Dec 2022, 20 Jan 2023)
  * if Class1RecvAbortOK is 0 then don't bother with the CAN byte at all (31 Oct 2022)
  * check that the modem isn't trying to deliver a message when we're trying to send
    binary data to it (16-17 Oct 2022)
  * prevent inherited values from creeping into subsequent xferfaxlog data (26 Aug 2022)
  * add external reference feature in dialrules (18 Aug 2022)
* Thu Jan 12 2023 Axel Braun <axel.braun@gmx.de>
- tiff_450.diff added
  updated to trunk r2695 for tiff 4.5 support - See CHANGES for details
* Mon Dec 26 2022 Axel Braun <axel.braun@gmx.de>
- version 7.0.6
  * add support for libtiff v4.4 (10 Jun 2022)
  * libtiff44.diff removed
  * cope with SSL Fax senders who skip Phase C (5 May 2022)
  * add ability to trace SSL Fax data reception (3 May 2022)
  * handle timeout OK response to +FRH=3 and +FRM=n (25 Apr 2022)
  * don't leave the modem waiting for a response when in SSL Fax (25 Apr 2022)
  * improve recovery from unexpected SSL Fax terminations during ECM (15, 18, 26 Apr 2022)
  * try to cope with false "no dialtone" results (4, 8 Apr 2022)
  * add initial support for SSL Fax Proxy servers (4, 23 Feb; 4, 19 Apr; 10, 24 Jun 2022)
  * buildrequirement for libssl added (Thanks Dimstar)
* Sat Jun  4 2022 Axel Braun <axel.braun@gmx.de>
- Project and download links switched to https
  libtiff44.diff added for tiff 4.x compatibility
* Sat Apr  2 2022 Axel Braun <axel.braun@gmx.de>
- version 7.0.5
  * hylafax.diff removed - included in source
  * extend Class1RecvAbortOK = 0 timeout to 500 ms (4 Dec 2021)
  * cope with Si2435 V.34/V.8 connection glitch (17, 19 Nov 2021)
  * cope with spurious +FCERROR or other delayed messages from modem (26 Oct 2021)
  * avoid letting corrupt RTC signals lead to RTN (26 Oct 2021)
  * don't refer to DCN as an invalid response in error messages (20 Oct 2021)
  * handle TSI during procedural interrupt (19 Oct 2021)
  * do better with waiting on prologue frames from receiver (13 Oct 2021)
  * cope with echo of ERR (13 Oct 2021)
  * run ps2fax, pdf2fax, tiff2fax, pcl2fax coverters as fax user (12 Oct 2021)
  * attempt to cope with receivers who signal RTN in ECM Phase D (23 Sep 2021)
  * fix hfaxd build when LDAP libs are not present (23 Sep 2021)
  * handle PPR echo after fourth PPR (22 Sep 2021)
  * don't use CRP when waiting for CFR following training (15 Sep 2021)
  * attempt to cope with receivers which signal CFR after PPS (14 Sep 2021)
  * cope with senders who signal FTT in Phase D (10 Sep 2021)
  * fix problem with handling NSF/CSI/DIS frame after CTC/EOR (9 Sep 2021)
  * cope with senders who signal PPS without the PPS FCF (9 Sep 2021)
  * handle echo of PPR when expecting CTC/EOR (8 Sep 2021)
  * add failure messages for unspecified training failures (7 Sep 2021)
  * don't use CRP when waiting for CTR (7 Sep 2021)
  * handle echo of EOR, don't use CRP when waiting for ERR (7 Sep 2021)
  * repeat PIN if sender repeats post-page or partial-page message (7-8 Sep 2021)
* Mon Oct 18 2021 Axel Braun <axel.braun@gmx.de>
- version 7.0.4
  * README.SUSE renamed
  * hylafax.diff added for boo#1191571 (pre-correction)
  * Dependencies on systemd-services adjusted
  * retry training twice at the same bitrate unless FTT (26 Aug 2021)
  * add missing reason messages for session failures (21 Aug 2021)
  * stop attempts to send or receive signals if the call ended prematurely (16-19 Aug 2021)
  * add Class1HasRMHookIndication (16 Aug 2021)
  * don't attempt sending DCN if we're already on hook (15, 17 Aug 2021)
  * end session sooner if receiver hangs up immediately after TCF or during prologue (14 Aug 2021)
  * fix some behavior following frame reception timeouts (13 Aug 2021)
  * improve behavior if procedural interrupt fails (12 Aug 2021)
  * handle sender repeating RR after we transmit MCF (10 Aug 2021)
  * add session logging of receipt of CFR/FTT signals (3 Aug 2021)
  * cope with receipt of PPR following CTC (3 Aug 2021)
  * attempt to cope with NSF/CSI/DIS after PPS, CTR, ERR, RR and improve coping with
    the same after MPS/EOP/EOM (2, 12, 14, 18 Aug 2021)
  * identify DCN after PPS as a receiver abort (2 Aug 2021)
  * attempt to cope with receipt of CTR after sending PPS (2 Aug 2021)
  * remove use of deprecated libtiff integer types and "register" storage class specifier (25 Jul 2021)
  * don't employ senderFumblesECM if V.34-Fax was negotiated (25 Jul 2021)
  * update configure to accept libtiff v4.2 and v4.3 (24 Jul 2021)
  * fix page handling "botch" if a job's first and previous attempts were on a proxy (20 Jul 2021)
  * fix data timeout for bitrates less than 14400 bps when non-zero scanline time (15 Jul 2021)
  * try to cope with T.38 invite stutter at beginning of send (15 Jul 2021)
  * decouple session logging from direct filesystem I/O (15 Jul 2021)
  * try to help receivers who may expect initial 1-bits to start high-speed data (8, 9 Jul, 4 Aug 2021)
  * improve tenacity of "persistent" ECM (26 Jun 2021)
  * maintain the same SSL Fax passcode during a single session (20 May 2021)
  * log detection of binary file transfer support in receivers (1 Apr 2021)
  * add support for SiLabs Si2417/Si2435 (5 Feb 2021)
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * hylafax-faxgetty@.service
  * hylafax-faxq.service
  * hylafax-faxqclean.service
  * hylafax-hfaxd.service
  * hylafax-usage.service
* Mon Jul 12 2021 Hans-Peter Jansen <hpj@urpla.net>
- Add hylafax service and helper for use with firewalld, and
  explain the details in README.SUSE.
* Sat May  8 2021 Axel Braun <axel.braun@gmx.de>
- Fix TW build by pretending tiff 4.4 is as good enough as 4.{0,1}
* Tue Jan 26 2021 Hans-Peter Jansen <hpj@urpla.net>
- Fix TW build by pretending tiff 4.2 is as good enough as 4.{0,1}
* Fri Oct  9 2020 Axel Braun <axel.braun@gmx.de>
- rearrange files-section (boo#1172731)
* Tue Aug 11 2020 Axel Braun <axel.braun@gmx.de>
- version 7.0.3
  * add UseSSLFax feature in sendfax, sendfax.conf, hyla.conf, and JobControl
  (31 Jul 2020)
  * be more resilient in listening for the Phase C carrier (30 Jul 2020)
  * make sure to return to command mode if HDLC receive times out (29 Jul 2020)
  * make faxmail ignore boundaries on parts other than multiparts (29 Jul 2020)
  * don't attempt to write zero bytes of data to a TIFF (29 Jul 2020)
  * don't ever respond to CRP with CRP (28 Jul 2020)
  * secure setup.cache/setup.modem - CVE-2020-15397 (27, 30 Jul 2020)
  * reset frame counter when a sender retransmits PPS for a previously confirmed
  ECM block (26 Jul 2020)
  * scrutinize PPM before concluding that the sender missed our MCF (23 Jul 2020)
  * fix modem recovery after SSL Fax failure (22, 26 Jul 2020)
  * ignore echo of PPR, RTN, CRP (10, 13, 21 Jul 2020)
  * attempt to handle NSF/CSI/DIS in Class 1 sending Phase D (6 Jul 2020)
  * run scripts directly rather than invoking them via a shell for security
  hardening (3-5 Jul 2020)
  * add senderFumblesECM feature (3 Jul 2020)
  * add support for PIN/PIP/PRI-Q/PPS-PRI-Q signals, add senderConfusesPIN
  feature, and utilize PIN for rare conditions where it may be helpful
  (2, 6, 13-14 Jul 2020)
  * add senderConfusesRTN feature (25-26 Jun 2020)
  * add MissedPageHandling feature (24 Jun 2020)
  * use and handle CFR in Phase D to retransmit Phase C (16, 23 Jun 2020)
  * cope with hearing echo of RR, CTC during Class 1 sending (15-17 Jun 2020)
  * fix listening for retransmission of MPS/EOP/EOM if it was received
  corrupt on the first attempt (15 Jun 2020)
  * secure temporary directory creation for faxsetup, faxaddmodem, and
  probemodem - CVE-2020-15396 (13 Jun 2020)
  * don't use CRP when receiving PPS/PPM as some senders think
  we are sending MCF (12 Jun 2020)
  * add BR_SSLFAX to show SSL Fax in notify and faxinfo output (1 Jun 2020)
  * have faxinfo put units on non-standard page dimensions (28 May 2020)
  * improve error messages for JobHost connection errors (22 May 2020)
  * fix perpetual blocking of jobs when a job preparation fails,
  attempt to fix similar blocking problems for bad jobs in
  batches, and add "unblock" faxconfig feature (21 May 2020)
  * ignore TCF if we're receiving an SSL Fax (31 Jan 2020)
  * fixes for build on FreeBSD 12.1 (31 Jan - 3 Feb 2020)
* Tue Jun  9 2020 Axel Braun <axel.braun@gmx.de>
- fix for boo#1172731
  VUL-0: EMBARGOED: CVE-2020-8024: hylafax+: Problematic permissions allow
    escalation from uucp to other users
  * adjusted authorisation
  * adjusted pre*/post* snipplets
* Fri Feb 14 2020 Axel Braun <axel.braun@gmx.de>
- Version 7.0.2
  * change FIXEDWIDTH default to better accommodate auto-rotation (13 Dec 2019)
  * prevent SSL_accept() from blocking (5 Dec 2019)
  * support libtiff v4.1 (5 Dec 2019)
  * fix ignoremodembusy feature broken by ModemGroup limits feature (16 Nov 2019)
* Fri Nov 22 2019 Hans-Peter Jansen <hpj@urpla.net>
- Version 7.0.1
  * create a client timeout setting and change the default from 60 to
  3600 seconds (26 Sep 2019)
  * extend timeout for receiving ECM frames (21 Aug 2019)
  * fix timeout in Class 1 frame reception (5 Aug 2019)
  * improve Class 1 protocol handling when MaxRecvPages exceeded (31 Jul 2019)
  * fix ModemGroup limit default (11 Jul 2019)
  * fix recovery for SSL Fax write failures (6 Jun 2019)
* Fri Nov 22 2019 Hans-Peter Jansen <hpj@urpla.net>
- build fails with libtiff 4.1: pretend, that 4.1 is similar to 4.0
* Thu Jul 18 2019 Axel Braun <axel.braun@gmx.de>
- Version 7.0.0
  * add LDAP features for compatibility with ActiveDirectory (25 Mar-1 Apr 2019)
  * fix recovery after SSL Fax "accept failure" (18 Mar 2019)
  * add TextFormat overstrike option and disable by default (6 Feb 2019)
  * fix the page size of cover sheets returned via notify (8 Jan 2019)
  * fix or silence numerous compiler warnings (19, 22, 28 Dec 2018)
  * fix pagehandling updating after a proxy has been used (7-8 Dec 2018)
  * add faxmail stderr output of RFC2047 decoding results (5 Dec 2018)
  * fix faxmail handling of headers encoded with UTF-8 (4 Dec 2018)
  * fix faxmail handling of base64-encoded text parts (4 Dec 2018)
  * add SSL Fax support (9-26, 29 Nov; 11, 18, 25 Dec 2018; 2, 7, 23 Jan 2019)
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce boilerplate generated from %%service_* by calling it just
  once.
* Fri Jan 18 2019 Axel Braun <axel.braun@gmx.de>
- faxgetty@ service removed from %%pre section, as it is only a placeholder
* Wed Jan 16 2019 Axel Braun <axel.braun@gmx.de>
- Dependency on hylafax-hfaxd for timers added
* Tue Jan  8 2019 Axel Braun <axel.braun@gmx.de>
- migrate from cron to systemd timers (boo#1115442)
* Tue Nov 27 2018 Hans-Peter Jansen <hpj@urpla.net>
- move textfmt to client package (used by sendfax only)
* Wed Nov 14 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not use tabs in spec
* Mon Nov 12 2018 Axel Braun <axel.braun@gmx.de>
- boo#1115532 JBIG-in-tiff conversion added
  (Build Requirement tiff, libtiff)
* Wed Sep 19 2018 Hans-Peter Jansen <hpj@urpla.net>
- add systemd hylafax.target
* Tue Sep 18 2018 Hans-Peter Jansen <hpj@urpla.net>
- version 5.6.1:
  * CVE-2018-17141: fixes multiple JPEG vulnerabilities affecting
    fax page reception in JPEG format. Specially crafted input may
    have allowed remote execution of arbitrary code (boo#1109084)
* Mon Sep 17 2018 Hans-Peter Jansen <hpj@urpla.net>
- use systemd template unit file for hylafax-faxgetty services
- fix services
* Sat Aug 25 2018 jengelh@inai.de
- Trim "enterprise" nonsense marketing.
* Wed Aug 15 2018 axel.braun@gmx.de
- version 5.6.0
  * notification.diff removed (part of 5.6.0 now)
  * some adjustments to assist AIX 6.1 builds (29 Jun 2018)
  * initial support for systemd in faxsetup (29 Jun 2018)
  * fix RFC2047 encoding by notify (27 Jun, 3 Jul 2018)
  * add jobcontrol PageSize feature (27 Jun 2018)
  * fix various compiler warnings (27 Jun 2018)
  * fix build on musl-based distribution (27 Jun 2018)
  * don't wait forever after +FRH:3 (18 Jun 2018)
  * add -A and -B options to tagtest (22 Feb 2018)
  * make tagtest use the TSI and CallerID data, if available (21 Feb 2018)
  * make tagtest use the date from the TIFF tags, if available,
  instead of "now" (20 Feb 2018)
  * pass Content-Type name and Content-Disposition filename
  information to faxmail MIMEHandlers (15 Jan 2018)
  * fix faxmail transition between a message and external types (15 Jan 2018)
  * fix warning for major and minor macros move to sysmacros.h (19 Dec 2017)
  * avoid pagehandling from introducing some unnecessary EOM signals (15 Dec 2017)
  * improve proxy connection error handling and logging (5 Dec 2017)
  * fix for reproducible builds (11 Sep 2017)
  * fix quote escaping in client apps (5 Sep 2017)
  * treat callingnumber  as null (25, 31 Aug 2017)
  * add initial ModemGroup limits feature (24 Aug 2017)
  * add CLEANFAXDATA and BADFAXLINES TIFF tags for ECM receptions (10 Aug 2017)
  * pass the user's uid onto the session log file for sent faxes (25 Jul 2017)
  * improve job waits to minimize triggers (30 May 2017)
  * increase FIFO read size and add logging information (25 May 2017)
  * add ProxyTaglineFormat and ProxyTSI features (13 Mar 2017)
* Sun Jun 17 2018 axel.braun@gmx.de
- boo#1091476: hfaxd needs to run as root
  otherwise error message '550 Cannot set privileges'
* Wed May  9 2018 axel.braun@gmx.de
- boo#1091476: faxq must always run as real user root
* Sun Mar  4 2018 jengelh@inai.de
- Remove uucp user creation for pre-1500: aaa_base provides
  this user/group already.
* Wed Feb 21 2018 axel.braun@gmx.de
- create user/group uucp
  adapt services to use uucp
  boo#1081899
* Sat Nov  4 2017 axel.braun@gmx.de
- bnc1052195 localized Email notification chops german Umlauts
  correction in bin/notify common_functions dictionary
  * notification.diff
* Fri Jul 21 2017 tchvatal@suse.com
- Drop hylafax+_rh.init
- Drop conditionals for distros we never build against in OBS
- Switch to LCMS2
- Add jbikgit-devel dependency so it is detected by configure
* Mon Apr  3 2017 axel.braun@gmx.de
- hylafax+ 5.5.9
  * fix a handful of compiler warnings for gcc v7 (13, 17 Feb 2017)
  * fix job rescheduling if the proxy connection attempt fails (13 Jul 2016)
  * increase the maximum number of triggers from 1024 to 4096 (13 Jul 2016)
  * eliminate faxq job priority "bounding" (13 Jul 2016)
  * attempt to detect premature non-ECM Phase C carrier loss (15 Jun 2016)
  * add missing recvq error message indications (6 May 2016)
  * fix tagtest support for multi-strip images (25 Mar 2016)
  * enhance textfmt wrapping to occur on word boundaries (24 Feb 2016)
* Sun Apr  3 2016 axel.braun@gmx.de
- hylafax+ 5.5.8
  * stop using mktemp() (5 Feb 2016)
  * fix LDAP authentication broken in 5.5.4 (24-26 Jan 2016)
  * reset senderinfo properly when receiving faxes (22 Jan 2016)
  * cope with V.21 HDLC carrier loss following +FRH:3 better (22, 26 Jan 2016)
  * increase the time Class1SwitchingCmd will wait for a response (14 Jan 2016)
  * undo faulty/incorrect previous "fix" to ntries/npages (13 Jan 2016)
  * fix short blocking problems in reading from the device (12 Jan 2016)
* Sun Feb  7 2016 axel.braun@gmx.de
- Fixed file list entry for faxcron
* Sat Feb  6 2016 axel.braun@gmx.de
- put texfmt manpage into the right package
* Tue Dec 29 2015 axel.braun@gmx.de
- hylafax 5.5.7
  * fix ntries counter to apply to pages instead of documents (5 Dec 2015)
  * reject jobs rejected by the proxy (18-19 Nov 2015)
  * add RewriteFaxName and RewriteFaxNumber jobcontrol features (14 Nov 2015)
  * improve Chinese translation (7 Oct 2015)
  * make faxsetup fix blind references in Fontmap.HylaFAX (3 Oct 2015)
  * use the remote time on proxy job submisisons (17 Sep 2015)
  * create more-secure hosts.hfaxd passwords by default (28 Aug 2015)
  * add admin login feature for faxstat (27 Aug 2015)
  * add ProxyJobTag jobcontrol feature (26 Aug 2015)
  * fix grevious calculation problem with Class1RestrictPoorSenders and
  Class1RestrictPoorDestinations (20 Aug 2015)
  * add application/binary MIMEConverter (17 Jul 2015)
  * fix DynamicConfig for Class 1 modem data format support (15 Jul 2015)
  * fix crash in tagline imaging due to glyph ascent (23 Jun 2015)
  * stop messing with the FIFO during installs and uninstalls (16 Jun 2015)
  * avoid conflicts with a TTY environment variable (15 Jun 2015)
  * fix dataTimeout esp for modems with large buffers in non-ECM (22 May 2015)
  * fix dataTimeout primarily affecting 7200 bps ECM sending (15 May 2015)
* Wed Dec 16 2015 pth@suse.de
- the proper name of the symlink is rchylafax.
* Mon Dec 14 2015 pth@suse.de
- Guard the inclusion of rchylafax+.
* Fri Dec 11 2015 pth@suse.de
- Only run cron jobs if hylafax is configured (boo#958150)
- Clean up the spec file a bit.
- Fix build.
- Export CFLAGS and CXXFLAGS so that the flags are imported by
  configure.
- Use 'make -j1' to prevent parallel building.
- post and postun sections are always need.
* Tue Jul 14 2015 axel.braun@gmx.de
- release 5.5.6
  * add typerules suggestion for PNG conversion (19 Mar 2015)
  * support more than 256 pages in Class 1 ECM (26 Feb 2015)
  * cope with application/pdf being encoded with quoted-printable
  in faxmail (13 Feb 2015)
  * fix npages and totpages recording in sendq when proxied (31 Jan 2015)
  * fix EOF reading fault on badly-formatted MIME in faxmail (12 Jan 2015)
  * fix hi-res tagline imaging on 64-bit systems (10 Dec 2014)
  * add support for seqf.increment files to indicate seqf
  incrementation (14 Nov 2014)
  * add support to faxmail to decode long-wrapped base64 (11, 14-15 Oct 2014)
  * fix proxy setting of null taglines (16 Sep 2014)
  * fix ModemWaitForConnect configuration setting (16 Sep 2014)
  * add debug messages for the attempt to locate a suitable modem
  for jobs (12 Aug 2014)
  * fix missed data type for libtiff v4 (31 Jul, 11 Aug 2014)
  * fix faxsend segfault caused by an empty TagLine field introduced in
  alignment features added in 5.5.5 (25 Jul 2014)
  * pass job priority to the proxy server (21 Jul 2014)
  * add JobHostID feature (16, 29-31 Jul 2014)
  * fix instances where a NULL return of crypt() is ignored (13 Jul 2014)
  * improve support for utmpx on BSD (10 Jul 2014)
  * apply some downstream patches from FreeBSD ports (10 Jul 2014)
  * use ps2write in faxmail pdf converter if pswrite is missing (6 Jul 2014)
  * modify FIFO usage and remove CONFIG_FIFOBUG and CONFIG_OPENFIFO (5 Jul 2014)
* Mon May  4 2015 axel.braun@gmx.de
- bnc#922402 update overwrites send-only settings to systemd config
* Thu Mar 12 2015 hpj@urpla.net
- fix standalone hylafax+-client fallout
* Thu Mar 12 2015 pth@suse.de
- Move libfaxutil into its own sub package (bnc#922017).
* Tue Feb 24 2015 axel.braun@gmx.de
- fix for bnc#856906 also for client package
* Wed Feb 18 2015 axel.braun@gmx.de
- dependency on tiff added
- build dependency on ghostscript
* Thu Feb 12 2015 axel.braun@gmx.de
- fix for bnc#856906
* Sun Dec 14 2014 axel.braun@gmx.de
- corrected typo (path) in README.SUSE
* Fri Nov 14 2014 axel.braun@gmx.de
-fix inclusion of initscript for SysV startup
* Wed Nov 12 2014 axel.braun@gmx.de
- Adapt README.SUSE to renamed service files
* Thu Nov  6 2014 pth@suse.de
- Rename README.SuSE to README.SUSE
- Remove systemd from service file names and adapt contents
  accordingly.
- Fix suse_version tests.
* Wed Nov  5 2014 pth@suse.de
- Fix spec file
* Tue Nov  4 2014 pth@suse.de
- Use macros for service handling
* Mon Nov  3 2014 pth@suse.de
- Include tarball.
- License is BSD-3-Clause.
- Set obsoletes and provides for hylafax-client.
* Mon Oct 27 2014 pth@suse.de
- Make spec a bit more readable.
* Sat Oct 18 2014 axel.braun@gmx.de
- added documentation for send-only environment
* Tue Oct 14 2014 axel.braun@gmx.de
- README.suse added (systemd-setup for hylafax)
* Mon Oct 13 2014 axel.braun@gmx.de
- added systemd-example for faxgetty
* Thu Nov 28 2013 axel.braun@gmx.de
- Split out hylafax client
* Tue Oct 29 2013 axel.braun@gmx.de
- New release 5.5.4
* Tue Jan 15 2013 Axel Braun <axel.braun@gmx.de>
- adapt spec for use with open Build service
* Tue Dec 11 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-6
- make dependency on systemd-units and system instead of /bin/systemctl
- modify systemd scriptlets
- use defattr to accomodate correct permissions for mock builds
* Sat Dec  8 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-5
- remove defattr from files
- rename patches and all but Source0 to hylafax+
- remove config(noreplace) from FIFO
- add /bin/systemctl build dependency for Fedora > 16
* Mon Dec  3 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-4
- add missing man pages
* Sun Nov  4 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-3
- spec optimizations
- clarify linkage in libfaxserver
- add systemd support
* Thu Nov  1 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-2
- change package name to hylafax+
- add Provides: hylafax
* Sat Oct 13 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-1
- update to 5.5.2
* Thu Jan 12 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.1-1
- update to 5.5.1
* Sat Dec 18 2010 Lee Howard <faxguy@howardsilvan.com> - 5.5.0-1
- update to 5.5.0
* Wed Oct 13 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.3-1
- update to 5.4.3
* Sun May  2 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.2-1
- update to 5.4.2
* Mon Feb 22 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.1-1
- update to 5.4.1
* Wed Dec 23 2009 Lee Howard <faxguy@howardsilvan.com> - 5.4.0-1
- update to 5.4.0
- add lcms-devel build dependency
* Sun Oct 25 2009 Lee Howard <faxguy@howardsilvan.com> - 5.3.0-1
- update to 5.3.0
* Sat Feb 28 2009 Lee Howard <faxguy@howardsilvan.com> - 5.2.9-1
- update to 5.2.9
- remove "Provides: hylafax"
* Sun Dec 21 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.8-1
- update to 5.2.8
* Mon Apr 28 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.4-3
- openldap-devel and pam-devel build dependencies
* Wed Apr 23 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.4-1
- update to 5.2.4
* Sat Mar 29 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.3-1
- update to 5.2.3
* Fri Jan 18 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.2-1
- make licensing BSD, initscript is not config, remove libtiff dependency
* Thu Nov  8 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.11-1
- add libtiff dependency
* Thu Aug  2 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.7-1
- update to 5.1.7
* Sat Jul 14 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.6-1
- accomodate MIMEConverter script location change
* Fri Mar 23 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.2-1
- made faxq's FIFO "noreplace" to keep upgrades from messing up a running faxq
* Thu Mar  8 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.1-1
- update to 5.1.1
* Thu Feb 22 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.0-1
- update to 5.1.0
* Thu Jan 11 2007 Lee Howard <faxguy@howardsilvan.com> - 5.0.4-1
- update to 5.0.4
* Mon Jan  1 2007 Lee Howard <faxguy@howardsilvan.com> - 5.0.3-1
- update to 5.0.3
* Wed Dec 13 2006 Lee Howard <faxguy@howardsilvan.com> - 5.0.2-1
- update to 5.0.2
* Wed Nov  1 2006 Lee Howard <faxguy@howardsilvan.com> - 5.0.0-1
- update to 5.0.0
- disable build of debuginfo package
- change ownership of config and dev to root,root
- move changelog to the end of the spec file
* Mon Sep 18 2006 Lee Howard <faxguy@howardsilvan.com> - 4.3.0.11-1
- update to 4.3.0.1
* Tue Apr 11 2006 Lee Howard <faxguy@howardsilvan.com> - 4.2.5.6-1
- update to 4.2.5.6
* Tue Apr 11 2006 Lee Howard <faxguy@howardsilvan.com> - 4.2.5.5-1
- initial 4.2.5.5 build
